.\"
.\" Copyright (c) 2004 Gordon D. Carrie. All rights reserved.
.\" 
.\" Licensed under the Open Software License version 2.1
.\" 
.\" Please address questions and feedback to user0@tkgeomap.org
.\" 
.\" @(#) $Id: tkgeomap.n,v 1.18 2007/01/23 20:30:25 tkgeomap Exp $
.\"
.so man.macros
.TH tkgeomap n 2 Tk "Tk Extensions tkgeomap"
.SH NAME
tkgeomap \- a package for displaying geographic lines and points in canvas
widgets.
.SH VERSION
2
.SH SYNOPSIS
\fBpackage require tkgeomap ?2?\fR
.SH INTRODUCTION
The \fBtkgeomap\fR package adds two item types to the \fBcanvas\fR widget.
The first type, \fBgeomap_lnarr\fR displays a linearray, which is an anonymous
set of points created with the \fBgeomap::lnarr\fR command.  The other type,
\fBgeomap_place\fR displays a named place created with the \fBgeomap::place\fR
command.  See the \fBtclgeomap\fR (n) man page for information on how to create
linearrays and places.
.SH DEFINING A GEOGRAPHIC MAP FOR GEOMAP_LNARR AND GEOMAP_PLACE ITEMS
The map that contains a \fBgeomap_lnarr\fR or \fBgeomap_place\fR item is
defined by the item's \fBcoords\fR and by its configuration.
This section describes the configuration options that define the map.
\fBgeomap_lnarr\fR and \fBgeomap_place\fR items have other type specific
configuration options, which are described in later sections.
Items can be drawn on the same map giving them the same map configuration.
This is most easily done by giving them a common tag and applying the map
configuration to items with that tag.
Here are the configuration options that define a map.
.TP
\fB-refpoint\fR \fI{lat lon}\fR
This option specifies the reference point of the item, which is the
\fI{lat lon}\fR at the \fIx, y\fR coordinates given as the item's
\fBcoords\fR.  Note that the reference point is not necessarily the location
of the place in a \fBgeomap_place\fR item, nor is it necessarily a point on
the linearray displayed in a \fBgeomap_lnarr\fR item.
It only helps define the map in which the item is displayed.
Other lat-lon's are positioned relative to the reference point.
A map can be shifted by changing the reference point with the \fB-refpoint\fR
option, or by changing the item's coordinates with the canvas \fBcoords\fR
or \fBmove\fR command.
A useful convention is to keep all item \fBcoords\fR at the center
of the canvas.  Then the \fBrefpoint\fR value is the lat-lon at the center
of the canvas, which is presumably a point of interest.
.TP
\fB-projection\fR \fIprojId\fR
Specifies the geographic projection for converting {lat lon} values
to map coordinates.  \fIprojId\fR must be the name of a command
returned by the \fBgeomap::projection \fR command.  See the \fBtclgeomap\fR
man page for information on how to create and manipulate projections.  If no
projection is specified, the item is not drawn.
.TP
\fB-rotation\fR \fIdoubleValueORdirection\fR
Specifies the map's orientation.  A value of \fB0.0\fR or \fBnorth\fR means
the top of the map is north.  A double value gives the number of degrees the
map is rotated clockwise from the conventional north-is-up orientation.
A value of \fBnorth\fR, \fBnneast\fR, \fBneast\fR, \fBeneast\fR, \fBeast\fR, 
\fBeseast\fR, \fBseast\fR, \fBsseast\fR, \fBsouth\fR, \fBsswest\fR, 
\fBswest\fR, \fBwswest\fR, \fBwest\fR, \fBwnwest\fR, \fBnwest\fR, or
\fBnnwest\fR gives the direction at the top of the map.
.TP
\fB-scale\fR \fIdoubleValue\fR
Specifies the cartographic scale for converting distances on the
projection plane to distances on the printed or displayed map.
.PP
The actual canvas coordinates of a \fBgeomap_lnarr\fR or \fBgeomap_place\fR
item can be retrieved by adding the keyword \fBdump\fR to the \fBcoords\fR
command.
.SH GEOMAP_LNARR ITEMS
Items of type \fBgeomap_lnarr\fR display and allow users to interact with
arrays of geographic points, called linearrays, created with the
\fBgeomap::lnarr\fR command.  See the
\fBtclgeomap\fR (n) man page for information on how to create and
manipulate linearrays.  \fBgeomap_lnarr\fR items can display linearrays in
three ways.  First, the points can be connected to make outlines.  Second, the
regions bounded by the points can be filled with a solid color, assuming they
are closed polygons.  Third, dots can be drawn at the points.  The
display method is determined by the item configuration, described below.
.sp
\fBgeomap_lnarr\fR items are created with widget commands of the following form:
.RS
\fIpathName\fR \fBcreate geomap_lnarr\fR \fIx y ?option value option value ...?
.RE
The options \fIx\fR and \fIy\fR give the canvas coordinates of the
\fBgeomap_lnarr\fR item's reference point, which is defined in its
configuration.  (See "DEFINING A GEOGRAPHIC MAP FOR GEOMAP_LNARR AND
GEOMAP_PLACE ITEMS" above).
After the coordinates there may be any number of \fIoption-value\fR
pairs, each of which sets one of the configuration options for the item. 
These same \fIoption value\fR pairs may be used in \fBitemconfigure\fR
widget commands to change the item's configuration.
.SH COMMON CANVAS OPTIONS FOR GEOMAP_LNARR ITEMS
\fBgeomap_lnarr\fR items support the following standard options.  See the
\fBcanvas\fR (n) man page for details.
.RS
.br
-fill
.br
-stipple
.br
-outline
.br
-tags
.RE
.SH SPECIAL OPTIONS FOR GEOMAP_LNARR ITEMS
In addition to the map options and standard options described above,
\fBgeomap_lnarr\fR items also recognize the following special options.
.TP
\fB-lnarr\fR \fIarrayName\fR
Specifies the name of a linearray to display in the item.  \fIarrayName\fR
should be the name of a linearray, usually created by the \fBgeomap::lnarr\fR
command.  See the \fBtclgeomap\fR (n) man page for information on how to
create linearrays.
When setting the linearray to display, \fIarrayName\fR MUST BE FULLY
QUALIFIED unless the array command is global.  If \fIarrayName\fR is an empty
string, no linearray will be displayed in the item.
When this option is used to retrieve the array name, such as with
\fBcget\fR, only the base name (without any \fB::\fR namespace qualifiers) is
returned.
If linearray \fIarrayName\fR is deleted, the item disappears from
the canvas, although the item continues to exist, and the value for this option
becomes an empty string.
.TP
\fB-width\fR \fIoutlineWidth\fR
Specifies the width of lines to draw.  \fIoutlineWidth\fR can be a coordinate
specifier as described in the \fBcanvas\fR (n) man page, or it can be
\fBnone\fR, \fB""\fR, or a negative number to indicate no lines should be
drawn.
.TP
\fB-linestyle\fR \fIstyle\fR
Specifies a linestyle, either \fBLineSolid\fR or \fBLineOnOffDash.
.TP
\fB-dashes\fR \fIdashLength\fR
Specifies the length of dashes it line style is \fBLineOnOffDash\fR.
.TP
\fB-smooth\fR \fIboolean\fR
Specifies whether to smooth the outline.  \fIboolean\fR must have one of the
forms accepted  by \fBTk_GetBoolean\fR.  Currently, only bezier smoothing
is available.  If set, the line will be rendered as a set of parabolic splines:
one spline is drawn for the first and second line segments, one for the second
and third, and so on.  Straight-line segments can be generated within
a curve by duplicating the end-points of the desired line segment.
.TP
\fB\-splinesteps \fInumber\fR
Specifies the degree of smoothness desired for curves:  each spline
will be approximated with \fInumber\fR line segments.  This
option is ignored unless the \fB\-smooth\fR option is true.
.TP
\fB-shape\fR \fIpolygonType\fR
Tells the type of shape to be filled in when using the \fB-fill\fR option.
This option is usually unnecessary, but might improve performance.
\fIShape\fR must be one of \fBConvex\fR, \fBNonconvex\fR, or \fBComplex\fR.
\fBConvex\fR means any segment connecting two points on the polygon does not
cross the polygon.  This type of shape can be faster to draw.  \fBNonconvex\fR
means the shape is not convex, but it does not cross itself.  \fBComplex\fR
means the shape might cross itself.  Results are undefined if a shape is given
as convex when it is not, or nonconvex when it is complex.  Note that the
assumption must apply for all projections used.
.TP
\fB-dotsize\fR \fInumber\fR
Specifies size in pixels of dots to draw at the segment ends.  If \fInumber\fR
is greater than \fB0\fR and the \fB-width\fR and \fB-fill\fR options are set
to \fB0\fR, the linearray will be displayed as a collection of dots,
which can be useful for making density plots or simple images.
.SH GEOMAP_PLACE ITEMS
Items of type \fBgeomap_place\fR display and allow users to interact with named
geographic locations.  See the \fBtclgeomap\fR (n) man page for information
on how to create and manipulate places.
\fBgeomap_place\fR items can display dots, bitmaps, and text at given geographic
locations.
.sp
\fBgeomap_place\fR items are created with widget commands of the following form:
.RS
\fIpathName\fR \fBcreate geomap_place\fR \fIx y ?option value option value ...?
.RE
The options \fIx\fR and \fIy\fR give the canvas coordinates of the
\fBgeomap_place\fR item's reference point, which is defined in its
configuration.  (See "DEFINING A GEOGRAPHIC MAP FOR GEOMAP_LNARR AND
GEOMAP_PLACE ITEMS" above).
After the coordinates there may be any number of \fIoption-value\fR
pairs, each of which sets one of the configuration options for the item. 
These same \fIoption value\fR pairs may be used in \fBitemconfigure\fR
widget commands to change the item's configuration.
.SH OPTIONS FOR GEOMAP_PLACE ITEMS
In addition to the map configuration options described above,
\fBgeomap_place\fR items recognize the following options.
.TP
\fB-place\fR \fIplaceName\fR
Specifies the name of a geoplace to display in the item.  \fIplaceName\fR
should be the name of a geoplace created with either the
\fBgeomap::place new\fR or \fBgeomap::place set\fR command.  See the
\fBtclgeomap\fR (n) man page for information on how to create places.
When setting the place to display, \fIplaceName\fR MUST BE FULLY QUALIFIED
unless the place command is global.  If \fIplaceName\fR is an empty string, no
place will be displayed in the item.
When this option is used to retrieve the place name, such as with
\fBcget\fR, only the base name (without any \fB::\fR namespace qualifiers) is
returned.
If geoplace \fIplaceName\fR is deleted, the item disappears from the
canvas, although the item continues to exist, and the value for this option
becomes an empty string.
.TP
\fB-dotcolor\fR \fIcolor\fR
Specifies the color of a dot drawn at the place.  \fIcolor\fR
may have any of the forms accepted by \fBTk_GetColor\fR.  If \fIcolor\fR is
an empty string, no dot is drawn at the place.
.TP
\fB-dotsize\fR \fIinteger\fR
Specifies the size of dot to draw at the place.  If \fIinteger\fR is \fB<= 0\fR,
no dot is drawn at the place.
.TP
\fB-bitmap\fR \fIbitmap\fR
Specifies a bitmap to draw at the place.  \fIbitmap\fR may have any
of the forms accepted by \fBTk_GetBitmap\fR.  If \fIbitmap\fR is an empty
string, no bitmap is drawn.
.TP
\fB-bitmapcolor\fR \fIcolor\fR
Specifies the bitmap color.
\fIcolor\fR specifies the bitmap foreground color, which is used
for bitmap pixels whose value is \fB1\fR.  \fIcolor\fR may have any of the
forms accepted by \fBTk_GetColor\fR.  If \fIcolor\fR is an empty string, no
bitmap is drawn at the place.
.TP
\fB-text\fR \fIstring\fR
Specifies a string of text to display at the place.
.TP
\fB-textcolor\fR \fIcolor\fR
Specifies the text color.  \fIcolor\fR may have any of the forms accepted by
\fBTk_GetColor\fR.
.TP
\fB-font\fR \fIfontName\fR
Specifies the font to use for the text item.  \fIfontName\fR may be any
string acceptable to \fBTk_GetFontStruct.\fR
.TP
\fB-anchor\fR \fIanchorPos\fR
Tells how to position the text relative to the place.  It may have any
of the forms accepted by \fBTk_GetAnchor.\fR For example, if \fIanchorPos\fR
is \fBcenter\fR then the text is centered on the place; if \fIanchorPos\fR
is \fBn\fR then the North end of the text will be at the place.
.TP
\fB-arrow\fR {\fIazimuth shaft_len tip_len\fR}
Draws an arrow at the place. The arrow will be oriented \fIazimuth\fR degrees
clockwise from true north. The shaft will be \fIshaft_len\fR pixels long.
The tip will have edges '\fIshaft_len\fR \fB*\fR \fItip_len\fR' pixels long,
i.e. \fItip_len\fR is a fraction of \fIshaft_len\fR.
.TP
\fB-arrowcolor\fR \fIcolor\fR
Specifies the arrow color.  \fIcolor\fR may have any of the forms accepted by
\fBTk_GetColor\fR.
.TP
\fB-tags\fR \fItagList\fR
Standard tags option to identify the item in canvas widget commands.
.SH SEE ALSO
.br
canvas (n)
.br
tclgeomap (n)
.SH FILES
These commands are added to \fBwish\fR by the \fBtkgeomap\fR package in file
\fBlibtkgeomap.so\fR or \fBlibtkgeomap.a\fR built by the tkgeomap-2.11.2
distribution.  It is part of the \fBtkgeomap\fR
executable, or can be added to the current interpreter with the
\fBload\fR or \fBpackage\fR commands.  Run \fBpackage names\fR to determine
if the \fBtkgeomap\fR package is present.  See the tkgeomap-2.11.2 distribution
for installation information.
.br
The code for the bezier spline computation was shamelessly lifted from
\fBtkTrig.c\fR and \fBtkUtil.c\fR of the Tk8.3.0 source distribution.
.SH AUTHOR
Gordon Carrie <user0@tkgeomap.org>
