/*
 * tkgeomap.c --
 *
 *	This file defines the structures and functions that implement the
 *	tkgeomap extension to Tcl, which adds the ability to display
 *	geographic data in Tcl.
 * 
 * Copyright (c) 2004 Gordon D. Carrie. All rights reserved.
 * 
 * Licensed under the Open Software License version 2.1
 * 
 * Please address questions and feedback to user0@tkgeomap.org
 *
 * @( *) $Id: tkgeomap.c,v 1.4 2004/09/22 21:23:25 tkgeomap Exp $
 *
 **********************************************************************
 *
 */

#include "tkgeomap.h"
#include "tkgeomapInt.h"


/*
 *------------------------------------------------------------------------
 *
 * Tkgeomap_Init --
 *
 * 	This procedure initializes the Tkgeomap interface and provides
 * 	the tkgeomap package.
 *
 * Results:
 *	A standard Tcl result.
 *
 * Side effects:
 * 	Initializes other interfaces.
 *
 *------------------------------------------------------------------------
 */

int
Tkgeomap_Init(interp)
    Tcl_Interp *interp;			/* Current interpreter */
{
    static int loaded;			/* If true, package is loaded */

    if (loaded) {
	return TCL_OK;
    }
#ifdef USE_TCL_STUBS
    if (Tcl_InitStubs(interp, TCL_VERSION, 0) == NULL) {
	return TCL_ERROR;
    }
#endif
#ifdef USE_TK_STUBS
    if (Tk_InitStubs(interp, TK_VERSION, 0) == NULL) {
	return TCL_ERROR;
    }
#endif
    if (Tclgeomap_Init(interp) != TCL_OK) {
	return TCL_ERROR;
    }
    if (TkgeomapLnArrInit(interp) != TCL_OK) {
	return TCL_ERROR;
    }
    if (TkgeomapPlaceInit(interp) != TCL_OK) {
	return TCL_ERROR;
    }
    Tcl_PkgProvide(interp, "tkgeomap", TKGEOMAP_VERSION);
    loaded = 1;
    return TCL_OK;
}
